@@ -1,5 +1,3 @@
-<html>
-<head><title>SquirrelMail Debugger</title></head>
 <?php
 
 /**
@@ -46,7 +44,9 @@ textdomain ('debugger');
 
 
 
-echo '<strong>GET:</strong><br />'
+echo '<html><head><title>' ._("SquirrelMail Debugger") 
+   . '</title></head><body><br />'
+   . '<strong>GET:</strong><br />'
    . $myget . '<br />'
    . '<strong>POST:</strong><br />'
    . $mypost . '<br />'
