@@ -107,7 +107,7 @@ function squirrelmail_plugin_init_debugger()
 function debugger_version()
 {
 
-   return '1.1';
+   return '1.2-1.4';
 
 }
 
